ActionParams

Struct ActionParams 

pub struct ActionParams {
    pub device_key: u32,
    pub group_key: u32,
    pub group_mask: u32,
    pub scheduled_time: Option<u64>,
    pub channel: u16,
}
Parameters used to construct an action command.

Fields

device_key: u32

Vendor-specific device key used to authorise the action.

group_key: u32

Group key identifying which devices should react to the action.

group_mask: u32

Group mask applied to the device key by receivers.

scheduled_time: Option<u64>

Optional scheduled time expressed in device clock ticks.

channel: u16

Stream channel identifier associated with the action.