pub struct GigeRegisterIo { /* private fields */ }Expand description
Blocking adapter turning an asynchronous GigeDevice into a RegisterIo
implementation.
The adapter uses a [tokio::runtime::Handle] to synchronously wait on GVCP
register transactions. All callers must ensure these methods are invoked
from outside of the runtime context to avoid nested block_on panics.
Implementations
Sourceimpl GigeRegisterIo
impl GigeRegisterIo
Sourcepub fn new(handle: Handle, device: GigeDevice) -> Self
pub fn new(handle: Handle, device: GigeDevice) -> Self
Create a new adapter using the provided runtime handle and device.